==> auth0_ai-0.1.0-py3-none-any.whl: auth0_ai/interrupts/federated_connection_interrupt.py <==
from typing import Dict, Any
from .auth0_interrupt import Auth0Interrupt

class FederatedConnectionInterrupt(Auth0Interrupt):
    """
    Error thrown when a tool call requires an access token for an external service.

    Throw this error if the service returns Unauthorized for the current access token.
    """

    code = "FEDERATED_CONNECTION_ERROR"

    def __init__(self, message: str, connection: str, scopes: list[str], required_scopes: list[str]):
        """
        Initializes a FederatedConnectionInterrupt instance.

        Args:
            message (str): Error message describing the reason for the interrupt.
            connection (str): The Auth0 connection name.
            scopes (list[str]): The scopes required to access the external service as stated in the authorizer.
            required_scopes (list[str]): The union between the current scopes of the Access Token plus the required scopes.
                                         This is the list of scopes that will be used to request a new Access Token.
        """
        super().__init__(message, self.code)
        self.connection = connection
        self.scopes = scopes
        self.required_scopes = required_scopes

    def to_json(self) -> Dict[str, Any]:
        """
        Serializes the interrupt to a JSON object.
        """
        return {
            **super().to_json(),
            "connection": self.connection,
            "scopes": self.scopes,
            "requiredScopes": self.required_scopes,
        }


class FederatedConnectionError(Exception):
    """
    Error thrown when a tool call requires an access token for an external service.

    The authorizer will automatically convert this class of error to FederatedConnectionInterrupt.
    """

    def __init__(self, message: str):
        """
        Initializes a FederatedConnectionError instance.

        Args:
            message (str): Error message describing the reason for the error.
        """
        super().__init__(message)

==> auth0_ai-1.0.0b1-py3-none-any.whl: auth0_ai/interrupts/federated_connection_interrupt.py <==
from typing import Final
from auth0_ai.interrupts.auth0_interrupt import Auth0Interrupt

class FederatedConnectionInterrupt(Auth0Interrupt):
    """
    Error thrown when a tool call requires an access token for an external service.

    Throw this error if the service returns Unauthorized for the current access token.
    """

    code: Final[str] = "FEDERATED_CONNECTION_ERROR"

    def __init__(self, message: str, connection: str, scopes: list[str], required_scopes: list[str]):
        """
        Initializes a FederatedConnectionInterrupt instance.

        Args:
            message (str): Error message describing the reason for the interrupt.
            connection (str): The Auth0 connection name.
            scopes (list[str]): The scopes required to access the external service as stated in the authorizer.
            required_scopes (list[str]): The union between the current scopes of the Access Token plus the required scopes.
                                         This is the list of scopes that will be used to request a new Access Token.
        """
        super().__init__(message, self.code)
        self.connection = connection
        self.scopes = scopes
        self.required_scopes = required_scopes
    
    def __copy__(self):
        return type(self)(
            self.args[0],
            self.connection,
            self.scopes,
            self.required_scopes
        )

    def __deepcopy__(self, memo):
        import copy
        return type(self)(
            copy.deepcopy(self.args[0], memo),
            copy.deepcopy(self.connection, memo),
            copy.deepcopy(self.scopes, memo),
            copy.deepcopy(self.required_scopes, memo),
        )


class FederatedConnectionError(Exception):
    """
    Error thrown when a tool call requires an access token for an external service.

    The authorizer will automatically convert this class of error to FederatedConnectionInterrupt.
    """

    def __init__(self, message: str):
        """
        Initializes a FederatedConnectionError instance.

        Args:
            message (str): Error message describing the reason for the error.
        """
        super().__init__(message)
